{
*******************************************************************
*  Dekleris Bill, April 1998.                                     *
*  e-mail address : quasar@hol.gr                                 *
*******************************************************************
*  This is a small utility which can be used                      *
*  to set file date and time stamps.                              *
* --------------------------------------------------------------- *
*  You may freely use both this utility and the source code.      *
*  If you eventually USE this utility,                            *
*  please notify me by e-mail ( quasar@hol.gr )                   *
*  (this is NO obligation of yours,                               *
*   I need it solely for statistical purposes!)                   *
* --------------------------------------------------------------- *
*  If you make any modifications or build another program based	*
*  on this utility, please let me know, I might be interested ... *
*******************************************************************
}

unit TouchF;

interface

uses
   Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
   StdCtrls, FileCtrl, ExtCtrls, IniFiles;

const
	IniFile_C = '.\touch.ini';

type

	TCoords = record
		X, Y, W, H : Integer;
		State : TWindowState;
	end;

	TForm1 = class(TForm)
   	Panel1: TPanel;
   	Panel2: TPanel;
   	DriveComboBox1: TDriveComboBox;
   	DirectoryListBox1: TDirectoryListBox;
   	Panel3: TPanel;
   	Edit1: TEdit;
   	Panel4: TPanel;
   	Panel5: TPanel;
   	Panel6: TPanel;
   	cmdTouch: TButton;
   	FileListBox1: TFileListBox;
   	Splitter1: TSplitter;
   	procedure FormCreate(Sender: TObject);
   	procedure cmdTouchClick(Sender: TObject);
   	procedure FileListBox1Click(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
  	private
   	{ Private declarations }
		fCoords : TCoords;
  	protected
   	procedure WMGetMinMaxInfo(var Msg : TWMGetMinMaxInfo); message WM_GETMINMAXINFO;
		procedure LoadPosition;
   	procedure ReadIniSettings;
   	procedure WriteIniSettings;
  	public
   	{ Public declarations }
  	end;

	procedure SetFileDate(sFileName, sDate: string);

var
   Form1: TForm1;

implementation

{$R *.DFM}

procedure SetFileDate(sFileName, sDate: string);
var
   fHandle: integer;
begin
   fHandle := FileOpen(sFileName, fmOpenWrite);
   try
      FileSetDate(fHandle, DateTimeToFileDate(StrToDateTime(trim(sDate))))
   finally
      FileClose(fHandle);
   end;
end;

procedure TForm1.FormCreate(Sender: TObject);
begin
   edit1.text := DateTimeToStr(now);
	ReadIniSettings;
	LoadPosition;
end;

procedure TForm1.FormDestroy(Sender: TObject);
begin
	WriteIniSettings;
end;

procedure TForm1.cmdTouchClick(Sender: TObject);
var
   i, n : integer;
begin
   n := FileListBox1.Items.Count-1;
   for i:=0 to n do
      if FileListBox1.Selected[i] then
         SetFileDate(FileListBox1.Items[i], edit1.text);
end;

procedure TForm1.WMGetMinMaxInfo(var Msg : TWMGetMinMaxInfo);
begin
   Msg.MinMaxInfo^.ptMinTrackSize := Point(333, 269); 
   inherited
end;

procedure TForm1.FileListBox1Click(Sender: TObject);
var
   i, n :         integer;
   bIsSelected :  boolean;
begin
   n := FileListBox1.Items.Count-1;
   bIsSelected := false;
   for i:=0 to n do begin
      if FileListBox1.Selected[i] then begin
         bIsSelected := true;
         break
      end
   end;
   cmdTouch.Enabled := bIsSelected;
end;

procedure TForm1.ReadIniSettings;
var
	Ini : TIniFile;
begin
	Ini := TIniFile.Create(IniFile_C);
	try
		fCoords.X := Ini.ReadInteger('Position', 'left', 10);
		fCoords.Y := Ini.ReadInteger('Position', 'top', 10);
		fCoords.W := Ini.ReadInteger('Position', 'width', Width);
		fCoords.H := Ini.ReadInteger('Position', 'height', Height);
		fCoords.State := TWindowState(Ini.ReadInteger('Position', 'State', Integer(WindowState)));
	finally
		Ini.Free;
	end;
end;

procedure TForm1.WriteIniSettings;
var
	Ini : TIniFile;
begin
	Ini := TIniFile.Create(IniFile_C);
	try
		Ini.WriteInteger('Position', 'left', Left);
		Ini.WriteInteger('Position', 'top', Top);
		Ini.WriteInteger('Position', 'width', Width);
		Ini.WriteInteger('Position', 'height', Height);
		Ini.WriteInteger('Position', 'state', Integer(fCoords.State));
	finally
		Ini.Free;
	end;
end;

procedure TForm1.LoadPosition;
begin
   if (fCoords.W > 0) and (fCoords.H > 0) then begin
      if (fCoords.State = wsNormal) then begin
         if BorderStyle = bsSizeable then
            MoveWindow(Handle, fCoords.X, fCoords.Y, fCoords.W, fCoords.H, True)
         else
            MoveWindow(Handle, fCoords.X, fCoords.Y, Width, Height, True)
      end else
         WindowState := fCoords.State
   end
end;

end.
